@@ -20,6 +20,10 @@
 #include <string.h>
 #include <stdlib.h>
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #include <sys/types.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
